@@ -18,7 +18,7 @@ enum eCommandKind {
     kCalc, kPrint,  kPuts, kLoad, 
     kWhile, kBreak, kExit, kIf, kSplit, kX, kJoin, kSelect, kLines, kRows,
     kMatch, kScan, kErase, kSub,
-    kRead, 
+    kRead, kClose, 
     kCd, 
     kAdd, kDel, kSelector, kMax, kMin,
     kExtName, kParentName, kNoExtName, 
