@@ -2223,7 +2223,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.0.9", 1);
+    setenv("SAPHIRE_VERSION", "3.1.0", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2998,10 +2998,10 @@ BOOL sWFd_flash(sWFd* self)
                     *self->mBuffer = 0;
                     return FALSE;
                 }
+                else if(errno = EPIPE) {
+                    break;
+                }
                 else {
-                    if(errno == EPIPE) {
-                        puts("EPIPE");
-                    }
     //printf("self->mFd %d\n", self->mFd);
                     perror("write(sWFd_flash)2");
                     return FALSE;
