@@ -699,7 +699,6 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                 return FALSE;
             }
 
-
             /// 引数名が指定されていなければスタックフレームを増やす ///
             vector_obj* fun_argv_before;
             vector_obj* fun_argv;
@@ -745,6 +744,11 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                 , nextout, nextin, nexterr, return_, blocks, FALSE);
             *return_ = FALSE; // ユーザー関数が復帰したらreturn終わり
 
+            /// スタックフレームの記録を消す
+            string_obj* sname_strace = vector_pop_back(gStackTraceFName);
+            int line_strace = (int)vector_pop_back(gStackTraceLineNum);
+
+
             if(strcmp(string_c_str(fun->arg_name), "") == 0) {
                 /// スタックを消す ///
                 hash_obj* stack = vector_pop_back(gStackFrame);
@@ -781,9 +785,6 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             saphire_set_local_var("RCODE", buf2);
 
             if(*rcode == -1) {
-                string_obj* sname_strace = vector_pop_back(gStackTraceFName);
-                int line_strace = (int)vector_pop_back(gStackTraceLineNum);
-
                 string_push_back(gErrMsg, string_c_str(sname_strace));
                 char tmp[1024];
                 snprintf(tmp, 1024, ":%d\n", line_strace);
@@ -1099,6 +1100,7 @@ int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pip
         int sline = statment->mLine;
         char* sname = string_c_str(statment->mFName);
 
+        /// $によるコマンド展開
         if(statment->mNotEvaled) {
             string_obj* cmdline = STRING_NEW("");
             if(expand_env(string_c_str(statment->mNotEvaled), cmdline, pipein, sname, &sline)) {
@@ -1124,6 +1126,7 @@ int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pip
                 return -1;
             }
         }
+        /// パースされている文を実行
         else {
             sigchld_block(1);
 
@@ -1228,9 +1231,7 @@ int saphire_load(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr)
     }
     (void)close(f);
 
-    int rcode = saphire_shell(string_c_str(str), fname, pipeout, pipein, pipeerr);
-
-    return rcode;
+    return saphire_shell(string_c_str(str), fname, pipeout, pipein, pipeerr);
 }
 
 
